@@ -2,21 +2,15 @@
 contains microservice Barrier and its instances
 """
 
-import uuid as _uuid
 
-from fdrtd.server.microservice import Microservice
-
-
-class Barrier(Microservice):
+class Barrier:
     """synchronizes parties through barriers"""
 
-    def __init__(self, bus, endpoint):
-        super().__init__(bus, endpoint)
+    def __init__(self):
         self.storage = {}
 
-    def create(self, tokens):
+    def create(self, uuid):
         """creates a new barrier"""
-        uuid = Barrier._create_deterministic_uuid(tokens)
         if uuid not in self.storage:
             self.storage[uuid] = BarrierInstance()
         return self.storage[uuid]
@@ -25,15 +19,6 @@ class Barrier(Microservice):
         """deletes a barrier"""
         del self.storage[uuid]
 
-    @staticmethod
-    def _create_deterministic_uuid(tokens):
-        uuid = _uuid.UUID('fede1a7e-0010-4e73-865d-a8e55a223b63')
-        uuid = _uuid.uuid5(uuid, 'Barrier')
-        if tokens is not None:
-            for token in tokens:
-                uuid = _uuid.uuid5(uuid, token)
-        return str(uuid)
-
 
 class BarrierInstance:
     """a synchronization barrier"""
